@@ -31,3 +31,12 @@ test_that("SortTree() works", {
                SortTree(UnrootTree(PectinateTree(5)))$edge)
   expect_equal('cladewise', attr(SortTree(PectinateTree(5)), 'order'))
 })
+
+test_that("SortTree.multiPhylo()", {
+  t1 <- as.phylo(123, 12)
+  t2 <- as.phylo(921, 12)
+
+  expect_identical(structure(list(SortTree(t1), SortTree(t2)),
+                             class = 'multiPhylo'),
+                   SortTree(c(t1, t2)))
+})
